@@ -21,7 +21,7 @@ class Storage(BaseStorage):
         """
 
         if not hasattr(self, 'db'):
-            self.db = anydbm.open(self.config['storage']['database_path'])
+            self.db = anydbm.open(self.config['storage']['database_path'], 'c')
         try:
             value = self.db[key]
         except KeyError:
